summaryrefslogtreecommitdiff
path: root/tests/Service_Config_Test.cpp
diff options
context:
space:
mode:
authornanbor <nanbor@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1999-07-05 09:52:56 +0000
committernanbor <nanbor@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1999-07-05 09:52:56 +0000
commita88a9ed99c706658a9e6cdb5cdedbb3d977c6a62 (patch)
tree80ad8b136bf72d82f20771a08d5a39f4ffbab77d /tests/Service_Config_Test.cpp
parentc4c4914a8a212dffcedccf3ab15ec1118eab5bbb (diff)
downloadATCD-a88a9ed99c706658a9e6cdb5cdedbb3d977c6a62.tar.gz
Pure unicode fixes.
Diffstat (limited to 'tests/Service_Config_Test.cpp')
-rw-r--r--tests/Service_Config_Test.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/tests/Service_Config_Test.cpp b/tests/Service_Config_Test.cpp
index 6f6e3b912a9..969df5f69c0 100644
--- a/tests/Service_Config_Test.cpp
+++ b/tests/Service_Config_Test.cpp
@@ -91,7 +91,7 @@ Test_Singleton::Test_Singleton (u_short variety)
if (variety_ != current_++)
{
ACE_DEBUG ((LM_ERROR,
- "ERROR: instance %u created out of order!\n",
+ ASYS_TEXT ("ERROR: instance %u created out of order!\n"),
variety_));
++error;
}
@@ -102,21 +102,21 @@ Test_Singleton::Test_Singleton (u_short variety)
Test_Singleton::~Test_Singleton (void)
{
- /* ACE_DEBUG ((LM_DEBUG, "Test_Singleton %u dtor\n", variety_)); */
+ /* ACE_DEBUG ((LM_DEBUG, ASYS_TEXT ("Test_Singleton %u dtor\n"), variety_)); */
if (variety_ != --current_)
{
ACE_OS::fprintf (stderr,
- "ERROR: instance %u destroyed out of order!\n",
+ ASYS_TEXT ("ERROR: instance %u destroyed out of order!\n"),
variety_);
/* ACE_DEBUG ((LM_ERROR, "ERROR: instance %u destroyed out of order!\n",
variety_)); */
++error;
}
}
static void
-run_test (int argc, char *argv[])
+run_test (int argc, ASYS_TCHAR *argv[])
{
// We need this scope to make sure that the destructor for the
// <ACE_Service_Config> gets called.
@@ -124,15 +124,15 @@ run_test (int argc, char *argv[])
ACE_ASSERT (daemon.open (argc, argv) != -1 || errno == ENOENT);
- ACE_Time_Value tv (argc > 1 ? atoi (argv[1]) : 2);
+ ACE_Time_Value tv (argc > 1 ? ACE_OS::atoi (argv[1]) : 2);
ACE_ASSERT (ACE_Reactor::run_event_loop (tv) == 0);
}
int
-main (int argc, char *argv[])
+main (int argc, ASYS_TCHAR *argv[])
{
- ACE_START_TEST ("Service_Config_Test");
+ ACE_START_TEST (ASYS_TEXT ("Service_Config_Test"));
for (u_int i = 0; i < VARIETIES; ++i)
{
@@ -140,7 +140,7 @@ main (int argc, char *argv[])
if (s == 0)
ACE_ERROR_RETURN ((LM_ERROR,
- "instance () allocate failed!\n"),
+ ASYS_TEXT ("instance () allocate failed!\n")),
1);
}
@@ -102,21 +102,21 @@ Test_Singleton::Test_Singleton (u_short variety)
variety_);
- /* ACE_DEBUG ((LM_ERROR, "ERROR: instance %u destroyed out of order!\n",
+ /* ACE_DEBUG ((LM_ERROR, ASYS_TEXT ("ERROR: instance %u destroyed out of order!\n"),
variety_)); */